Skip to content

This gives missing values an explicit factor level, ensuring that they appear in summaries and on plots.

Usage

fct_explicit_na(f, na_level = "(Missing)")

Arguments

f

A factor (or character vector).

na_level

Level to use for missing values: this is what NAs will be changed to.

Examples

f1 <- factor(c("a", "a", NA, NA, "a", "b", NA, "c", "a", "c", "b"))
fct_count(f1)
#> # A tibble: 4 × 2
#>   f         n
#>   <fct> <int>
#> 1 a         4
#> 2 b         2
#> 3 c         2
#> 4 NA        3

f2 <- fct_explicit_na(f1)
fct_count(f2)
#> # A tibble: 4 × 2
#>   f             n
#>   <fct>     <int>
#> 1 a             4
#> 2 b             2
#> 3 c             2
#> 4 (Missing)     3